@@ -1,16 +1,18 @@
+from __future__ import unicode_literals
+
 import json
-import urllib
-from urlparse import urlparse, parse_qs
 
 from django.test import TestCase, RequestFactory
-from django.contrib.auth import get_user_model
 from django.core.urlresolvers import reverse
 from django.utils import timezone
 
+from ..compat import urlparse, parse_qs, urlencode, get_user_model
 from ..models import Application, Grant
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 
+from .test_utils import TestCaseUtils
+
 
 # mocking a protected resource view
 class ResourceView(ProtectedResourceView):
@@ -18,7 +20,7 @@ class ResourceView(ProtectedResourceView):
         return "This is a protected resource"
 
 
-class BaseTest(TestCase):
+class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
         self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
@@ -48,7 +50,7 @@ class TestAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': 'fakeclientid',
             'response_type': 'code',
         })
@@ -63,7 +65,7 @@ class TestAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': self.application.client_id,
             'response_type': 'code',
             'state': 'random_state_string',
@@ -90,7 +92,7 @@ class TestAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': self.application.client_id,
             'response_type': 'code',
         })
@@ -108,7 +110,7 @@ class TestAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': self.application.client_id,
             'response_type': 'code',
             'redirect_uri': 'http://forbidden.it',
@@ -118,6 +120,22 @@ class TestAuthorizationCodeView(BaseTest):
         response = self.client.get(url)
         self.assertEqual(response.status_code, 400)
 
+    def test_pre_auth_wrong_response_type(self):
+        """
+        Test error when passing a wrong response_type in query string
+        """
+        self.client.login(username="test_user", password="123456")
+
+        query_string = urlencode({
+            'client_id': self.application.client_id,
+            'response_type': 'WRONG',
+        })
+        url = "{url}?{qs}".format(url=reverse('authorize'), qs=query_string)
+
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 302)
+        self.assertIn("error=unauthorized_client", response['Location'])
+
     def test_code_post_auth_allow(self):
         """
         Test authorization code is given for an allowed request with response_type: code
@@ -135,7 +153,9 @@ class TestAuthorizationCodeView(BaseTest):
 
         response = self.client.post(reverse('authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
-        self.assertIn('http://example.it/?state=random_state_string&code=', response['Location'])
+        self.assertIn('http://example.it?', response['Location'])
+        self.assertIn('state=random_state_string', response['Location'])
+        self.assertIn('code=', response['Location'])
 
     def test_code_post_auth_deny(self):
         """
@@ -173,7 +193,25 @@ class TestAuthorizationCodeView(BaseTest):
 
         response = self.client.post(reverse('authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
-        self.assertIn('http://example.it/?error', response['Location'])
+        self.assertIn('http://example.it?error', response['Location'])
+
+    def test_code_post_auth_forbidden_redirect_uri(self):
+        """
+        Test authorization code is given for an allowed request with a forbidden redirect_uri
+        """
+        self.client.login(username="test_user", password="123456")
+
+        form_data = {
+            'client_id': self.application.client_id,
+            'state': 'random_state_string',
+            'scopes': 'read write',
+            'redirect_uri': 'http://forbidden.it',
+            'response_type': 'code',
+            'allow': True,
+        }
+
+        response = self.client.post(reverse('authorize'), data=form_data)
+        self.assertEqual(response.status_code, 400)
 
 
 class TestAuthorizationCodeTokenView(BaseTest):
@@ -206,15 +244,12 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'code': authorization_code,
             'redirect_uri': 'http://example.it'
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
-        content = json.loads(response.content)
+        content = json.loads(response.content.decode("utf-8"))
         self.assertEqual(content['token_type'], "Bearer")
         self.assertEqual(content['scope'], "read write")
         self.assertEqual(content['expires_in'], oauth2_settings.ACCESS_TOKEN_EXPIRE_SECONDS)
@@ -230,10 +265,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'code': 'BLAH',
             'redirect_uri': 'http://example.it'
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
@@ -249,10 +281,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'code': 'BLAH',
             'redirect_uri': 'http://example.it'
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
@@ -271,10 +300,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'code': 'BLAH',
             'redirect_uri': 'http://example.it'
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
@@ -291,10 +317,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
             'code': authorization_code,
             'redirect_uri': 'http://example.it'
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, 'BOOM!')
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, 'BOOM!')
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
@@ -320,7 +343,7 @@ class TestAuthorizationCodeTokenView(BaseTest):
         response = self.client.post(reverse('token'), data=token_request_data)
         self.assertEqual(response.status_code, 200)
 
-        content = json.loads(response.content)
+        content = json.loads(response.content.decode("utf-8"))
         self.assertEqual(content['token_type'], "Bearer")
         self.assertEqual(content['scope'], "read write")
         self.assertEqual(content['expires_in'], oauth2_settings.ACCESS_TOKEN_EXPIRE_SECONDS)
@@ -349,12 +372,10 @@ class TestAuthorizationCodeProtectedResource(BaseTest):
             'code': authorization_code,
             'redirect_uri': 'http://example.it'
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
+
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
-        content = json.loads(response.content)
+        content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
         # use token to access the resource
