@@ -1,13 +1,16 @@
+from __future__ import unicode_literals
+
 import json
 
 from django.test import TestCase, RequestFactory
-from django.contrib.auth import get_user_model
 from django.core.urlresolvers import reverse
 
-from ..models import Application, Grant
+from ..compat import get_user_model
+from ..models import Application
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
 
+from .test_utils import TestCaseUtils
 
 # mocking a protected resource view
 class ResourceView(ProtectedResourceView):
@@ -15,7 +18,7 @@ class ResourceView(ProtectedResourceView):
         return "This is a protected resource"
 
 
-class BaseTest(TestCase):
+class BaseTest(TestCaseUtils, TestCase):
     def setUp(self):
         self.factory = RequestFactory()
         self.test_user = get_user_model().objects.create_user("test_user", "test@user.com", "123456")
@@ -47,16 +50,12 @@ class TestPasswordTokenView(BaseTest):
             'username': 'test_user',
             'password': '123456',
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id,
-                                     self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 200)
 
-        content = json.loads(response.content)
+        content = json.loads(response.content.decode("utf-8"))
         self.assertEqual(content['token_type'], "Bearer")
         self.assertEqual(content['scope'], "read write")
         self.assertEqual(content['expires_in'], oauth2_settings.ACCESS_TOKEN_EXPIRE_SECONDS)
@@ -70,10 +69,7 @@ class TestPasswordTokenView(BaseTest):
             'username': 'test_user',
             'password': 'NOT_MY_PASS',
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id, self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
         self.assertEqual(response.status_code, 400)
@@ -86,14 +82,10 @@ class TestPasswordProtectedResource(BaseTest):
             'username': 'test_user',
             'password': '123456',
         }
-        user_pass = '{0}:{1}'.format(self.application.client_id,
-                                     self.application.client_secret)
-        auth_headers = {
-            'HTTP_AUTHORIZATION': 'Basic ' + user_pass.encode('base64'),
-        }
+        auth_headers = self.get_basic_auth_header(self.application.client_id, self.application.client_secret)
 
         response = self.client.post(reverse('token'), data=token_request_data, **auth_headers)
-        content = json.loads(response.content)
+        content = json.loads(response.content.decode("utf-8"))
         access_token = content['access_token']
 
         # use token to access the resource
